@@ -1,11 +1,10 @@
 use chrono::Utc;
 use serde::ser::Serialize;
-use serde_json::{Value, from_value, to_value};
 use serde_json::map::Map;
+use serde_json::{from_value, to_value, Value};
 
-use errors::{Result, ErrorKind, new_error};
 use crypto::Algorithm;
-
+use errors::{new_error, ErrorKind, Result};
 
 /// Contains the various validations that are applied after decoding a token.
 ///
@@ -38,17 +37,11 @@ pub struct Validation {
     ///
     /// Defaults to `true`.
     pub validate_exp: bool,
-    /// Whether to validate the `iat` field.
-    ///
-    /// It will return an error if the time in the `iat` field is in the future.
-    ///
-    /// Defaults to `true`.
-    pub validate_iat: bool,
     /// Whether to validate the `nbf` field.
     ///
     /// It will return an error if the current timestamp is before the time in the `nbf` field.
     ///
-    /// Defaults to `true`.
+    /// Defaults to `false`.
     pub validate_nbf: bool,
     /// If it contains a value, the validation will check that the `aud` field is the same as the
     /// one provided and will error otherwise.
@@ -95,7 +88,6 @@ impl Default for Validation {
             leeway: 0,
 
             validate_exp: true,
-            validate_iat: false,
             validate_nbf: false,
 
             iss: None,
@@ -107,21 +99,9 @@ impl Default for Validation {
     }
 }
 
-
-
 pub fn validate(claims: &Map<String, Value>, options: &Validation) -> Result<()> {
     let now = Utc::now().timestamp();
 
-    if options.validate_iat {
-        if let Some(iat) = claims.get("iat") {
-            if from_value::<i64>(iat.clone())? > now + options.leeway {
-                return Err(new_error(ErrorKind::InvalidIssuedAt));
-            }
-        } else {
-            return Err(new_error(ErrorKind::InvalidIssuedAt));
-        }
-    }
-
     if options.validate_exp {
         if let Some(exp) = claims.get("exp") {
             if from_value::<i64>(exp.clone())? < now - options.leeway {
@@ -175,54 +155,16 @@ pub fn validate(claims: &Map<String, Value>, options: &Validation) -> Result<()>
     Ok(())
 }
 
-
 #[cfg(test)]
 mod tests {
-    use serde_json::{to_value};
-    use serde_json::map::Map;
     use chrono::Utc;
+    use serde_json::map::Map;
+    use serde_json::to_value;
 
     use super::{validate, Validation};
 
     use errors::ErrorKind;
 
-    #[test]
-    fn iat_in_past_ok() {
-        let mut claims = Map::new();
-        claims.insert("iat".to_string(), to_value(Utc::now().timestamp() - 10000).unwrap());
-        let validation = Validation { validate_exp: false, validate_iat: true, ..Validation::default() };
-        let res = validate(&claims, &validation);
-        assert!(res.is_ok());
-    }
-
-    #[test]
-    fn iat_in_future_fails() {
-        let mut claims = Map::new();
-        claims.insert("iat".to_string(), to_value(Utc::now().timestamp() + 100000).unwrap());
-        let validation = Validation { validate_exp: false, validate_iat: true, ..Validation::default() };
-        let res = validate(&claims, &validation);
-        assert!(res.is_err());
-
-        match res.unwrap_err().kind() {
-            &ErrorKind::InvalidIssuedAt => (),
-            _ => assert!(false),
-        };
-    }
-
-    #[test]
-    fn iat_in_future_but_in_leeway_ok() {
-        let mut claims = Map::new();
-        claims.insert("iat".to_string(), to_value(Utc::now().timestamp() + 50).unwrap());
-        let validation = Validation {
-            leeway: 1000 * 60,
-            validate_iat: true,
-            validate_exp: false,
-            ..Default::default()
-        };
-        let res = validate(&claims, &validation);
-        assert!(res.is_ok());
-    }
-
     #[test]
     fn exp_in_future_ok() {
         let mut claims = Map::new();
@@ -248,10 +190,7 @@ mod tests {
     fn exp_in_past_but_in_leeway_ok() {
         let mut claims = Map::new();
         claims.insert("exp".to_string(), to_value(Utc::now().timestamp() - 500).unwrap());
-        let validation = Validation {
-            leeway: 1000 * 60,
-            ..Default::default()
-        };
+        let validation = Validation { leeway: 1000 * 60, ..Default::default() };
         let res = validate(&claims, &validation);
         assert!(res.is_ok());
     }
@@ -272,7 +211,8 @@ mod tests {
     fn nbf_in_past_ok() {
         let mut claims = Map::new();
         claims.insert("nbf".to_string(), to_value(Utc::now().timestamp() - 10000).unwrap());
-        let validation = Validation { validate_exp: false, validate_nbf: true, ..Validation::default() };
+        let validation =
+            Validation { validate_exp: false, validate_nbf: true, ..Validation::default() };
         let res = validate(&claims, &validation);
         assert!(res.is_ok());
     }
@@ -281,7 +221,8 @@ mod tests {
     fn nbf_in_future_fails() {
         let mut claims = Map::new();
         claims.insert("nbf".to_string(), to_value(Utc::now().timestamp() + 100000).unwrap());
-        let validation = Validation { validate_exp: false, validate_nbf: true, ..Validation::default() };
+        let validation =
+            Validation { validate_exp: false, validate_nbf: true, ..Validation::default() };
         let res = validate(&claims, &validation);
         assert!(res.is_err());
 
@@ -405,10 +346,7 @@ mod tests {
     fn aud_string_ok() {
         let mut claims = Map::new();
         claims.insert("aud".to_string(), to_value("Everyone").unwrap());
-        let mut validation = Validation {
-            validate_exp: false,
-            ..Validation::default()
-        };
+        let mut validation = Validation { validate_exp: false, ..Validation::default() };
         validation.set_audience(&"Everyone");
         let res = validate(&claims, &validation);
         assert!(res.is_ok());
@@ -418,10 +356,7 @@ mod tests {
     fn aud_array_of_string_ok() {
         let mut claims = Map::new();
         claims.insert("aud".to_string(), to_value(["UserA", "UserB"]).unwrap());
-        let mut validation = Validation {
-            validate_exp: false,
-            ..Validation::default()
-        };
+        let mut validation = Validation { validate_exp: false, ..Validation::default() };
         validation.set_audience(&["UserA", "UserB"]);
         let res = validate(&claims, &validation);
         assert!(res.is_ok());
@@ -431,10 +366,7 @@ mod tests {
     fn aud_type_mismatch_fails() {
         let mut claims = Map::new();
         claims.insert("aud".to_string(), to_value("Everyone").unwrap());
-        let mut validation = Validation {
-            validate_exp: false,
-            ..Validation::default()
-        };
+        let mut validation = Validation { validate_exp: false, ..Validation::default() };
         validation.set_audience(&["UserA", "UserB"]);
         let res = validate(&claims, &validation);
         assert!(res.is_err());
@@ -449,10 +381,7 @@ mod tests {
     fn aud_correct_type_not_matching_fails() {
         let mut claims = Map::new();
         claims.insert("aud".to_string(), to_value("Everyone").unwrap());
-        let mut validation = Validation {
-            validate_exp: false,
-            ..Validation::default()
-        };
+        let mut validation = Validation { validate_exp: false, ..Validation::default() };
         validation.set_audience(&"None");
         let res = validate(&claims, &validation);
         assert!(res.is_err());
@@ -466,10 +395,7 @@ mod tests {
     #[test]
     fn aud_missing_fails() {
         let claims = Map::new();
-        let mut validation = Validation {
-            validate_exp: false,
-            ..Validation::default()
-        };
+        let mut validation = Validation { validate_exp: false, ..Validation::default() };
         validation.set_audience(&"None");
         let res = validate(&claims, &validation);
         assert!(res.is_err());
